==> jc-1.4.0.tar.gz: javax/swing/text/StyleConstants__24CharacterConstants.h <==
// public class javax.swing.text.StyleConstants$CharacterConstants

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 33098ca6f888e073 javax_swing_text_StyleConstants
// @dep_class 58dd244ef4a3c67c javax_swing_text_StyleConstants__24CharacterConstants

// header file dependencies
// @dep_header javax_swing_text_StyleConstants

#include "javax/swing/text/StyleConstants.h"

#ifndef _JC_javax_swing_text_StyleConstants__24CharacterConstants_H_
#define _JC_javax_swing_text_StyleConstants__24CharacterConstants_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$sub_refs	_jc_javax_swing_text_StyleConstants__24CharacterConstants$sub_refs;
typedef struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$sub_nonrefs	_jc_javax_swing_text_StyleConstants__24CharacterConstants$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$refs	_jc_javax_swing_text_StyleConstants__24CharacterConstants$refs;
typedef struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$nonrefs	_jc_javax_swing_text_StyleConstants__24CharacterConstants$nonrefs;
typedef struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$object	_jc_javax_swing_text_StyleConstants__24CharacterConstants$object;

typedef struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$fields_struct	_jc_javax_swing_text_StyleConstants__24CharacterConstants$fields_struct;
typedef const struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$vmethods	_jc_javax_swing_text_StyleConstants__24CharacterConstants$vmethods;
typedef const struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$vtable	_jc_javax_swing_text_StyleConstants__24CharacterConstants$vtable;
typedef const struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$vtype	_jc_javax_swing_text_StyleConstants__24CharacterConstants$vtype;

// Class fields structure
struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$fields_struct {
	struct _jc_java_lang_Object$object	*Background;
	struct _jc_java_lang_Object$object	*BidiLevel;
	struct _jc_java_lang_Object$object	*Bold;
	struct _jc_java_lang_Object$object	*ComponentAttribute;
	struct _jc_java_lang_Object$object	*Family;
	struct _jc_java_lang_Object$object	*Foreground;
	struct _jc_java_lang_Object$object	*IconAttribute;
	struct _jc_java_lang_Object$object	*Italic;
	struct _jc_java_lang_Object$object	*Size;
	struct _jc_java_lang_Object$object	*StrikeThrough;
	struct _jc_java_lang_Object$object	*Subscript;
	struct _jc_java_lang_Object$object	*Superscript;
	struct _jc_java_lang_Object$object	*Underline;
};
extern _jc_javax_swing_text_StyleConstants__24CharacterConstants$fields_struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$class_fields;

// Constructors
extern void _jc_javax_swing_text_StyleConstants__24CharacterConstants$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$object *, struct _jc_java_lang_String$object *);

// Static methods
extern void _jc_javax_swing_text_StyleConstants__24CharacterConstants$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$vmethods {
};

// Vtable
struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_StyleConstants$vmethods	javax_swing_text_StyleConstants;
	_jc_javax_swing_text_StyleConstants__24CharacterConstants$vmethods	javax_swing_text_StyleConstants__24CharacterConstants;
};

// Vtype
struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyleConstants__24CharacterConstants$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$refs {
    _jc_javax_swing_text_StyleConstants__24CharacterConstants$sub_refs	javax_swing_text_StyleConstants__24CharacterConstants;
    _jc_javax_swing_text_StyleConstants$sub_refs	javax_swing_text_StyleConstants;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_StyleConstants$sub_nonrefs	javax_swing_text_StyleConstants;
    _jc_javax_swing_text_StyleConstants__24CharacterConstants$sub_nonrefs	javax_swing_text_StyleConstants__24CharacterConstants;
};

// Object instance structure
struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$object {
	_jc_javax_swing_text_StyleConstants__24CharacterConstants$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyleConstants__24CharacterConstants$vtype	*vtype;
	_jc_javax_swing_text_StyleConstants__24CharacterConstants$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyleConstants__24CharacterConstants$vtype _jc_javax_swing_text_StyleConstants__24CharacterConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyleConstants__24CharacterConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyleConstants__24CharacterConstants$class_object;

#endif	/* _JC_javax_swing_text_StyleConstants__24CharacterConstants_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/StyleConstants__24CharacterConstants.h <==
// public class javax.swing.text.StyleConstants$CharacterConstants

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 602dc460083efcf4 javax_swing_text_StyleConstants
// @dep_class 3a7d39a24077af7f javax_swing_text_StyleConstants__24CharacterConstants

// header file dependencies
// @dep_header javax_swing_text_StyleConstants

#include "javax/swing/text/StyleConstants.h"

#ifndef _JC_javax_swing_text_StyleConstants__24CharacterConstants_H_
#define _JC_javax_swing_text_StyleConstants__24CharacterConstants_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$sub_refs	_jc_javax_swing_text_StyleConstants__24CharacterConstants$sub_refs;
typedef struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$sub_nonrefs	_jc_javax_swing_text_StyleConstants__24CharacterConstants$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$refs	_jc_javax_swing_text_StyleConstants__24CharacterConstants$refs;
typedef struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$nonrefs	_jc_javax_swing_text_StyleConstants__24CharacterConstants$nonrefs;
typedef struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$object	_jc_javax_swing_text_StyleConstants__24CharacterConstants$object;

typedef struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$fields_struct	_jc_javax_swing_text_StyleConstants__24CharacterConstants$fields_struct;
typedef const struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$vmethods	_jc_javax_swing_text_StyleConstants__24CharacterConstants$vmethods;
typedef const struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$vtable	_jc_javax_swing_text_StyleConstants__24CharacterConstants$vtable;
typedef const struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$vtype	_jc_javax_swing_text_StyleConstants__24CharacterConstants$vtype;

// Class fields structure
struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$fields_struct {
	struct _jc_java_lang_Object$object	*Background;
	struct _jc_java_lang_Object$object	*BidiLevel;
	struct _jc_java_lang_Object$object	*Bold;
	struct _jc_java_lang_Object$object	*ComponentAttribute;
	struct _jc_java_lang_Object$object	*Family;
	struct _jc_java_lang_Object$object	*Foreground;
	struct _jc_java_lang_Object$object	*IconAttribute;
	struct _jc_java_lang_Object$object	*Italic;
	struct _jc_java_lang_Object$object	*Size;
	struct _jc_java_lang_Object$object	*StrikeThrough;
	struct _jc_java_lang_Object$object	*Subscript;
	struct _jc_java_lang_Object$object	*Superscript;
	struct _jc_java_lang_Object$object	*Underline;
};
extern _jc_javax_swing_text_StyleConstants__24CharacterConstants$fields_struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$class_fields;

// Constructors
extern void _jc_javax_swing_text_StyleConstants__24CharacterConstants$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_javax_swing_text_StyleConstants__24CharacterConstants$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$vmethods {
};

// Vtable
struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_StyleConstants$vmethods	javax_swing_text_StyleConstants;
	_jc_javax_swing_text_StyleConstants__24CharacterConstants$vmethods	javax_swing_text_StyleConstants__24CharacterConstants;
};

// Vtype
struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyleConstants__24CharacterConstants$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$refs {
    _jc_javax_swing_text_StyleConstants__24CharacterConstants$sub_refs	javax_swing_text_StyleConstants__24CharacterConstants;
    _jc_javax_swing_text_StyleConstants$sub_refs	javax_swing_text_StyleConstants;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_StyleConstants$sub_nonrefs	javax_swing_text_StyleConstants;
    _jc_javax_swing_text_StyleConstants__24CharacterConstants$sub_nonrefs	javax_swing_text_StyleConstants__24CharacterConstants;
};

// Object instance structure
struct _jc_javax_swing_text_StyleConstants__24CharacterConstants$object {
	_jc_javax_swing_text_StyleConstants__24CharacterConstants$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyleConstants__24CharacterConstants$vtype	*vtype;
	_jc_javax_swing_text_StyleConstants__24CharacterConstants$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyleConstants__24CharacterConstants$vtype _jc_javax_swing_text_StyleConstants__24CharacterConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyleConstants__24CharacterConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyleConstants__24CharacterConstants$class_object;

#endif	/* _JC_javax_swing_text_StyleConstants__24CharacterConstants_H_ */
